@@ -133,7 +133,8 @@
 #' @seealso  \code{\link[bestNormalize]{boxcox}}, \code{\link{orderNorm}},
 #'   \code{\link{yeojohnson}}
 #' @export
-bestNormalize <- function(x, standardize = TRUE, 
+bestNormalize <- function(x, 
+                          standardize = TRUE, 
                           allow_orderNorm = TRUE,
                           allow_lambert_s = FALSE,
                           allow_lambert_h = FALSE,
@@ -147,11 +148,12 @@ bestNormalize <- function(x, standardize = TRUE,
                           quiet = FALSE, 
                           tr_opts = list(),
                           new_transforms = list(), 
-                          norm_stat_fn= NULL, ...) {
+                          norm_stat_fn = NULL, 
+                          ...) {
   stopifnot(is.numeric(x))
   x.t <- list()
   methods <- c("no_transform", "arcsinh_x", 'boxcox', 
-               "log_x", "sqrt_x", 'yeojohnson')
+               "log_x", "double_reverse_log", "sqrt_x", 'yeojohnson')
   
   # Change no transform to center_scale if standardize = T
   if(standardize)
@@ -188,7 +190,7 @@ bestNormalize <- function(x, standardize = TRUE,
   methods <- methods[order(methods)]
   args <- lapply(methods, function(i) {
     val <- list(standardize = standardize)
-    if(i %in% c("orderNorm", "exp_x", "log_x")) {
+    if(i %in% c("orderNorm", "exp_x", "log_x", "double_reverse_log")) {
       val[['warn']] <- warn
     } else if(i == "lambert_s") {
       val[["type"]] <- "s"
@@ -313,6 +315,7 @@ print.bestNormalize <- function(x, ...) {
     "lambert_h" = "Lambert's W (type h)",
     "lambert_s" = "Lambert's W (type s)",
     "log_x" = "Log_b(x+a)",
+    "double_reverse_log" = "Double Reversed Log_b(x+a)",
     "no_transform" = "No transform",
     "orderNorm" = "orderNorm (ORQ)",
     "sqrt_x" = "sqrt(x + a)",
@@ -342,9 +345,10 @@ print.bestNormalize <- function(x, ...) {
 
 #' @rdname bestNormalize
 #' @param x A `bestNormalize` object.
+#' @param ... not used
 #' @importFrom tibble tibble
 #' @export
-tidy.bestNormalize <- function(x) {
+tidy.bestNormalize <- function(x, ...) {
   
   chosen_name <- class(x$chosen_transform)[1]
   chosen_tr <- x$chosen_transform
